pygeodesy.geodesici.XDict

Package pygeodesy :: Module geodesici :: Class XDict |
[frames] | no frames]

# Class XDict

    object --+
             |
          dict --+
                 |
       named.ADict --+
                     |
                    XDict

4+Item result from Intersectool and Intersector methods `All`, `Closest`, `Next` and `Segment` with the intersection offsets `sA`, `sB` and `sX0` in `meter` and the coincidence indicator `c`, an `int`, +1 for parallel, -1 for anti-parallel or 0 otherwise.

Offsets `sA` and `sB` are distances measured along geodesic line `glA` respectively `glB`, but `sX0` is the L1-distance between the intersection and the origin `X0`.

If present, distance `sAB` and angular distance `aAB` represent the separation between the intersection point on geodesic lines `glA` and `glB` in `meter` respectively `degrees`, typically below `5e-9 meter` or `5 nm` respectively `5e-14 degrees` or `1 n"`.

For segments, indicators `kA` and `kB` are `0` if the segments intersect or `-1` or `+1` if the intersection is before the start, respectively after the end of the segment, similar to Intersection3Tuple. Segment indicator `k` is Karney's `segmode`, equal `kA * 3 + kB`.

Instance Methods
__add__(self, other) |
__eq__(self, other) x==y |
__iadd__(self, other) |
__le__(self, other) x<=y |
__lt__(self, other) x<y |
__ne__(self, other) x!=y |
L1(self, other=None) Return the `L1` distance. |
Inherited from `named.ADict`: `__getattr__`, `__repr__`, `__setattr__`, `__str__`, `set_`, `toRepr`, `toStr` Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__ge__`, `__getattribute__`, `__getitem__`, `__gt__`, `__init__`, `__iter__`, `__len__`, `__new__`, `__setitem__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values`, `viewitems`, `viewkeys`, `viewvalues` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__subclasshook__`

Class Variables
Inherited from `dict`: `__hash__`

Properties
Inherited from `named.ADict`: `iteration`, `typename` Inherited from `object`: `__class__`

Method Details

### __eq__ (self, other) (Equality operator) |
x==y Overrides: dict.__eq__ (inherited documentation)

### __le__ (self, other) (Less-than-or-equals operator) |
x<=y Overrides: dict.__le__ (inherited documentation)

### __lt__ (self, other) (Less-than operator) |
x<y Overrides: dict.__lt__ (inherited documentation)

### __ne__ (self, other) |
x!=y Overrides: dict.__ne__ (inherited documentation)